function plotprobCRF(nNodes)

[pathstr,name,ext,versn] = fileparts(mfilename('fullpath'));

filename = sprintf('%s%sdata%sprobCRF%03d.mat',...
                   pathstr,filesep,filesep,nNodes);

if ~exist(filename,'file')
   fprintf('Please run runprobCRF(%d) first.\n',nNodes);
   return;
else
   load(filename);
end



% Set plotting properties
fs = 16; % Font size
lw = 3;  % Line width
ms = 10; % Marker size

figure(1); clf; gca; hold on;
y = info1.fHist(end);
plot(info1.evalHist,info1.fHist,'b.', ...
     info2.evalHist,info2.fHist,'r.', ...
     info3.evalHist,info3.fHist,'g.');
plot([0,max([info1.evalHist(end),info2.evalHist(end),info3.evalHist(end)])],[y,y],'k--');
set(gca,'YScale','log');
set(gca,'XScale','log');
set(gca,'Fontsize',fs);
title('f(x) versus function evaluations');
legend('Block Gauss-Seidel','SPG','Projected gradient');
hold off;


figure(2); clf; gca; hold on;
y = info1.fHist(end) + lambda*info1.normHist(end);
plot([0,max([info1.evalHist(end), info2.evalHist(end), info3.evalHist(end)])],[y,y],'k--');
plot(info1.evalHist,info1.fHist+lambda*info1.normHist,'b.', ...
     info2.evalHist,info2.fHist+lambda*info2.normHist,'r.', ...
     info3.evalHist,info3.fHist+lambda*info3.normHist,'g.');
hold off;
set(gca,'XScale','log');
title('f(x)+lambda*groupnorm(x) versus function evaluations');

figure(3); clf; gca; hold on;
y1 = info1.fHist(end)+lambda*info1.normHist(end);
y2 = info2.fHist(end)+lambda*info2.normHist(end);
y3 = info3.fHist(end)+lambda*info3.normHist(end);
y4 = info4.fHist(end)+lambda*info4.normHist(end);
y = min([y1 y2 y3 y4]);
p1 = abs((info1.fHist+lambda*info1.normHist) - y);
p2 = abs((info2.fHist+lambda*info2.normHist) - y);
p3 = abs((info3.fHist+lambda*info3.normHist) - y);
p4 = abs((info4.fHist+lambda*info4.normHist) - y);
q1 = cummin(p1);
q2 = cummin(p2);
q3 = cummin(p3);
q4 = cummin(p4);
x1 = info1.evalHist;
x2 = info2.evalHist;
x3 = info3.evalHist;
x4 = info4.evalHist;
% $$$ h = plot(info1.evalHist,cummin(p1),'r-.', ...
% $$$          info4.evalHist,cummin(p4),'k:',...
% $$$          info3.evalHist,cummin(p3),'g--', ...
% $$$          info2.evalHist,cummin(p2),'b-');
h = plot(x1(1:5:end),q1(1:5:end),'r-.', ...
         x4(1:40:end),q4(1:40:end),'k:',...
         x3(1:4:end),q3(1:4:end),'g--', ...
         x2(1:1:end),q2(1:1:end),'b-');
hold off;

set(gca,'YScale','log');
set(gca,'XScale','log');
set(gca,'Fontsize',fs);
set(h,'LineWidth',lw);
xlabel('Function evaluations');
ylabel('f - f_{opt}');
yl = get(gca,'YLim');
ylim([1e-8,5e4]); set(gca,'YTick',[1e-8,1e-4,1,1e4]);
xlim([1,1e3]);    set(gca,'XTick',[1,1e1,1e2,1e3]);
set(gca,'XMinorTick','off');
%xl = get(gca,'XLim');
%xl(2) = length(p4);
%xlim(xl);
box on;
legend('Location','SouthWest','BCD','Smooth','PG','SPG');
%title('abs(f(x)+lambda*groupnorm(x) - optimum) versus function
%evaluations');
exportplot(nNodes,3);


function exportplot(id,idx)

filename = sprintf('plotprobCRF%03d%c.pdf',id,char('a'+idx-1));
cmd = sprintf('print -dpdf %s',filename);

if ~ispc
  cmd = sprintf('!pdfcrop %s %s',filename,filename);
end
