function [samples] = UGM_Sample_VarMCMC(nodePot,edgePot,edgeStruct,infoStruct,varProb)
% MCMC sampler that switches between random walk MH and variational MF
% sampling
%
% varProb is the probability of trying the variational move
% (set to 0 for purely variational proposals)

[nNodes,maxStates] = size(nodePot);
nEdges = size(edgePot,3);
edgeEnds = edgeStruct.edgeEnds;
V = edgeStruct.V;
E = edgeStruct.E;
nStates = infoStruct.nStates;
maxIter = infoStruct.maxIter;

infoStruct_sub = infoStruct;
infoStruct_sub.maxIter = infoStruct.maxIter+1;
[sampleMF,nodeBelMF] = UGM_Sample_MF(nodePot,edgePot,edgeStruct,infoStruct_sub);

% Initialize
y = sampleMF(:,1);
MFsample = 2;
logWeightOld = UGM_LogConfigurationPotential(y,nodePot,edgePot,edgeEnds);

samples = zeros(nNodes,0);
accepted = 0;
for i = 1:maxIter
    
    y_old = y;
    
    % Generate Proposal
    transProbOld = 1;
    transProb = 1;
    if rand < varProb
        % Random Walk Metropolis-Hastings
        n = mod(i,nNodes)+1;
        transState = [1:y(n)-1 y(n)+1:nStates(n)];
        y(n) = transState(ceil(rand*(nStates(n)-1)));
    else
        % Variational Sample
        y = sampleMF(:,MFsample);
        MFsample = MFsample+1;
        for n = 1:nNodes
           transProbOld = transProbOld*nodeBelMF(n,y_old(n));
           transProb = transProb*nodeBelMF(n,y(n));
        end
    end
    
    % Calculate Weight of Proposal
    logWeight = UGM_LogConfigurationPotential(y,nodePot,edgePot,edgeEnds);
    
    % Accept/Reject Proposal
    if rand < exp(logWeight - logWeightOld)*(transProbOld/transProb)
        accepted = accepted+1;
        logWeightOld = logWeight;
    else
        y = y_old;
    end

    % Record Sample
    samples(:,i) = y;

    if mod(i,10) == 0
        fprintf('Accpted = %d out of %d, Acceptance Rate = %.2f\n',accepted,i,accepted/i);
    end
    
end